## The Python-Easy Project
# Made by Tarvey@github quaqak@youtube

## How to use it?
# Its easy! just type "pip install easypython"

## Commands
# show - Shows text on the screen
# iw = Prints and waits for user input.
# docmd - Runs a command in bash or cmd.

## Functions
# iswin() - Checks if a user is on windows.
if iswin():
    show("Hi Windows User!")